//
//  PlayerCentral.m
//  Auto Layout demo
//
//  The player central hosts four labeled player views with their scores
//
//  Created by Bertils mini on 2010-01-21.
//  Copyright 2010-14 Sork Software. All rights reserved.
//  Version 1.2 adds support for the PlayerViewContainer. Sep 2014
//

#import "PlayerCentral.h"
#import "Defines.h"
#import "PlayerView.h"
#import "PlayerViewContainer.h"

@interface PlayerCentral ()
@end

@implementation PlayerCentral

// An early initializer, received before the Player View initializations
// Comes before the game controller initialization but after the container view init
- (id)initWithCoder:(NSCoder*)coder {
  if (self = [super initWithCoder:coder]) {
    
  }
  return self;
}

// Create and load four player bars, successively rotated 90 degrees CCW
// Translation is no longer required as the auto layout constraints will move the rotated bars into position
// The PlayerViewContainer was added as part of the corrections needed under iOS 8
- (void)loadPlayerViews {
  // First view: Place in bottom left base position for a 320 pixel square
  // Second view: Rotate and translate 90 degrees CCW ie -90 degrees
  CGAffineTransform transform1 = CGAffineTransformMakeRotation(degreesToRadians(270));
  // Third view: Rotate 180 degrees CCW
  CGAffineTransform transform2 = CGAffineTransformConcat(transform1, transform1);
  // Fourth view: Rotate 270 degrees CCW
  CGAffineTransform transform3 = CGAffineTransformConcat(transform2, transform1);
  
  // Create a PlayerView from its own nib file, the returned array is disregarded
  // Files Owner of the nib file is this Player Central
  // The playerView outlet is connected to the created view by the bundle loader
  // PlayerCentral tag is 4, the PlaceView tag is 5, and PlayerView/Container tags are 6-9
  // In the Player View the background is 10, the indicator 11, the label 12, and the score 13
  
  for (int i = 0; i < 4; i++) {
    [[NSBundle mainBundle] loadNibNamed:@"PlayerView" owner:self options:nil];
    
    switch (i) {
      case 0:
        self.playerView.playerLabel.text = @"South 南";
        self.playerView.tag = 0;
        [self.playerViewContainer0 addSubview:self.playerView];
        break;
      case 1: {
        self.playerView.transform = transform1;
        self.playerView.playerLabel.text = @"East 東";
        self.playerView.tag = 1;
        [self.playerViewContainer1 addSubview:self.playerView];
        break;
      }
      case 2: {
        self.playerView.transform = transform2;
        self.playerView.playerLabel.text = @"North 北";
        self.playerView.tag = 2;
        [self.playerViewContainer2 addSubview:self.playerView];
        break;
      }
      case 3: {
        self.playerView.transform = transform3;
        self.playerView.playerLabel.text = @"West 西";
        self.playerView.tag = 3;
        [self.playerViewContainer3 addSubview:self.playerView];
        break;
      }
    }
    self.playerView = nil;
  }
}

// The PlayerView corresponding to the player container tag (method not used here)
// As the receiver – PlayerCentral – is included in the UIView viewWithTag: search,
// the PC tag is set to 4, the PlaceView is 5, and the containerView 6-9
// The method viewWithTag: returns a UIView, hence the cast to PlayerView
- (PlayerView *)playerViewWithTag:(NSUInteger)tag {
  UIView *conView = [self viewWithTag:tag];
  PlayerView *thePV = [[conView subviews] objectAtIndex:0];
  
  return  thePV;
}

/* PC constraints added in IB - in iOS 7
 "<NSLayoutConstraint:0x8e82910 H:[PlayerCentral:0x8e81ef0(320)]>",
 "<NSLayoutConstraint:0x8e82940 V:[PlayerCentral:0x8e81ef0(320)]>",
 "<NSLayoutConstraint:0x8e82970 PlayerCentral:0x8e81ef0.centerX == PlaceView:0x8e822a0.centerX>",
 "<NSLayoutConstraint:0x8e829a0 PlayerCentral:0x8e81ef0.centerY == PlaceView:0x8e822a0.centerY>",
 PC constraints added by layoutPlayerViews
 "<NSLayoutConstraint:0xa46f6c0 V:[PlaceView:0x8e822a0]-(0)-[PlayerView:0x8e83ff0]>",
 "<NSLayoutConstraint:0xa46f710 V:[PlayerView:0x8e83ff0]-(0)-|   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa4755c0 H:|-(0)-[PlayerView:0x8e83ff0]   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa474b40 H:[PlayerView:0x8e83ff0]-(0)-[PlayerView:0xa474f30]>",
 "<NSLayoutConstraint:0xa474b90 V:[PlayerView:0xa474e10]-(0)-[PlayerView:0xa474f30]>",
 "<NSLayoutConstraint:0xa46e9f0 V:[PlayerView:0xa474f30]-(0)-|   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa46ea60 H:[PlaceView:0x8e822a0]-(0)-[PlayerView:0xa474f30]>",
 "<NSLayoutConstraint:0xa475970 H:[PlayerView:0xa474f30]-(0)-|   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa4759a0 V:|-(0)-[PlayerView:0xa474e10]   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa4759d0 V:[PlayerView:0xa474e10]-(0)-[PlaceView:0x8e822a0]>",
 "<NSLayoutConstraint:0xa478410 H:[PlayerView:0xa476f20]-(0)-[PlayerView:0xa474e10]>",
 "<NSLayoutConstraint:0xa478440 H:[PlayerView:0xa474e10]-(0)-|   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa478470 V:|-(0)-[PlayerView:0xa476f20]   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa4784c0 V:[PlayerView:0xa476f20]-(0)-[PlayerView:0x8e83ff0]>",
 "<NSLayoutConstraint:0xa478560 H:|-(0)-[PlayerView:0xa476f20]   (Names: '|':PlayerCentral:0x8e81ef0 )>",
 "<NSLayoutConstraint:0xa46ea20 H:[PlayerView:0xa476f20]-(0)-[PlaceView:0x8e822a0]>"
 */

@end
